==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/df/d74/vehicle__base_8h.js <==
var vehicle__base_8h =
[
    [ "NewGRFCache", "db/d1f/structNewGRFCache.html", "db/d1f/structNewGRFCache" ],
    [ "VehicleCache", "d9/d7d/structVehicleCache.html", "d9/d7d/structVehicleCache" ],
    [ "VehicleSpriteSeq", "d5/d52/structVehicleSpriteSeq.html", "d5/d52/structVehicleSpriteSeq" ],
    [ "RefitDesc", "d1/de1/structRefitDesc.html", "d1/de1/structRefitDesc" ],
    [ "Vehicle", "d0/dba/structVehicle.html", "d0/dba/structVehicle" ],
    [ "SpecializedVehicle", "d5/d32/structSpecializedVehicle.html", "d5/d32/structSpecializedVehicle" ],
    [ "FreeUnitIDGenerator", "dd/d52/structFreeUnitIDGenerator.html", "dd/d52/structFreeUnitIDGenerator" ],
    [ "FOR_ALL_VEHICLES", "df/d74/vehicle__base_8h.html#a027d4a7d226a89b1a25b6cc57c8981c7", null ],
    [ "FOR_ALL_VEHICLES_FROM", "df/d74/vehicle__base_8h.html#ace5f0960dbb6c09cb56ec7a06f315461", null ],
    [ "FOR_ALL_VEHICLES_OF_TYPE", "df/d74/vehicle__base_8h.html#a815854d65029557a4f33821ad4ad7032", null ],
    [ "VehiclePool", "df/d74/vehicle__base_8h.html#ae009766a55a373630b73d4da5527aa49", null ],
    [ "GroundVehicleSubtypeFlags", "df/d74/vehicle__base_8h.html#a475541e2c3751ab4cdbbd462e5234c0d", [
      [ "GVSF_FRONT", "df/d74/vehicle__base_8h.html#a475541e2c3751ab4cdbbd462e5234c0da7f80cdde6f9512987ac9c2eb3f230b49", null ],
      [ "GVSF_ARTICULATED_PART", "df/d74/vehicle__base_8h.html#a475541e2c3751ab4cdbbd462e5234c0da13b8cbca661303a477a18b2b4374b4e1", null ],
      [ "GVSF_WAGON", "df/d74/vehicle__base_8h.html#a475541e2c3751ab4cdbbd462e5234c0dabb276682c9516f01f31a632b7793a922", null ],
      [ "GVSF_ENGINE", "df/d74/vehicle__base_8h.html#a475541e2c3751ab4cdbbd462e5234c0dac6cdd99aad9394764b5371eb118dba76", null ],
      [ "GVSF_FREE_WAGON", "df/d74/vehicle__base_8h.html#a475541e2c3751ab4cdbbd462e5234c0dab1ee1247b67762752ac3e36838c04ef7", null ],
      [ "GVSF_MULTIHEADED", "df/d74/vehicle__base_8h.html#a475541e2c3751ab4cdbbd462e5234c0da86f2c03e45fd1fbc14ec2ba0bb7a0d7a", null ]
    ] ],
    [ "NewGRFCacheValidValues", "df/d74/vehicle__base_8h.html#a97190ca989d0b359655a18b4722b7d6c", [
      [ "NCVV_POSITION_CONSIST_LENGTH", "df/d74/vehicle__base_8h.html#a97190ca989d0b359655a18b4722b7d6ca2c2aab4770602781883f87b6d8d2c546", null ],
      [ "NCVV_POSITION_SAME_ID_LENGTH", "df/d74/vehicle__base_8h.html#a97190ca989d0b359655a18b4722b7d6ca6a9bed0fbb26e12b8ea7400eea56de42", null ],
      [ "NCVV_CONSIST_CARGO_INFORMATION", "df/d74/vehicle__base_8h.html#a97190ca989d0b359655a18b4722b7d6ca234159842b57b3f3cf3cccc71daf1c7b", null ],
      [ "NCVV_COMPANY_INFORMATION", "df/d74/vehicle__base_8h.html#a97190ca989d0b359655a18b4722b7d6ca1fd5696aa9d674cd19f3f61c5ec6642c", null ],
      [ "NCVV_POSITION_IN_VEHICLE", "df/d74/vehicle__base_8h.html#a97190ca989d0b359655a18b4722b7d6cac5a52081cfe3b22b83b82945dcedd736", null ],
      [ "NCVV_END", "df/d74/vehicle__base_8h.html#a97190ca989d0b359655a18b4722b7d6caf259659a5cd9def2fe25c84b75a57225", null ]
    ] ],
    [ "VehicleFlags", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7a", [
      [ "VF_LOADING_FINISHED", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aaee56c17502c55d5bde3de57f06e43b01", null ],
      [ "VF_CARGO_UNLOADING", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aa748e67d3dbc538693603017d41d3132a", null ],
      [ "VF_BUILT_AS_PROTOTYPE", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aa6af17c90853fe89b17791602f0be9ef0", null ],
      [ "VF_TIMETABLE_STARTED", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aaf2a9f8891396be7414e5d37fd6e66696", null ],
      [ "VF_AUTOFILL_TIMETABLE", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aac941394da43cb9fc99e37801fd395603", null ],
      [ "VF_AUTOFILL_PRES_WAIT_TIME", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aae699a90ef294038d061380cec2680912", null ],
      [ "VF_STOP_LOADING", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aa27c012b7139ac9e9d9b321929c8764c3", null ],
      [ "VF_PATHFINDER_LOST", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aad89bed75b420510be68cd254426a01b8", null ],
      [ "VF_SERVINT_IS_CUSTOM", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aaf0b635e74343f06e2d461e26652c89a2", null ],
      [ "VF_SERVINT_IS_PERCENT", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aa4a664a2c0c83bdcaa9ba3d8fa612cf32", null ]
    ] ],
    [ "VehStatus", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4ec", [
      [ "VS_HIDDEN", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4ecacc5dfba7e128cac462925a6564a55a97", null ],
      [ "VS_STOPPED", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4ecaad499f07ddcf89b774b972c1eec71bb9", null ],
      [ "VS_UNCLICKABLE", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4eca31366b8e7860d2100059a7cfa3a64937", null ],
      [ "VS_DEFPAL", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4ecaeb25e06ebad9abc16e8966815ee60126", null ],
      [ "VS_TRAIN_SLOWING", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4eca5ae3d8fea88773afcc312f721d385ce5", null ],
      [ "VS_SHADOW", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4eca82271078c80dc08bdc23e1a7eddc72fd", null ],
      [ "VS_AIRCRAFT_BROKEN", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4eca6860fc59f73e91177c928b2497d45156", null ],
      [ "VS_CRASHED", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4ecae36b782cf9c378a7f06727ecdab935e9", null ]
    ] ],
    [ "VisualEffect", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4", [
      [ "VE_OFFSET_START", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4ac84ac123de33e694a50ad59356b15485", null ],
      [ "VE_OFFSET_COUNT", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a6bcab2e0b1a59f01baad45ddbf832408", null ],
      [ "VE_OFFSET_CENTRE", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a41c2bdecc196b8d5c8c076b1fc080458", null ],
      [ "VE_TYPE_START", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a65429232930562e61d22b43e6d21e1d3", null ],
      [ "VE_TYPE_COUNT", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a3e226d79eb465e44dade4cf11bb81385", null ],
      [ "VE_TYPE_DEFAULT", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a0574594bd49aef1310099f6e9310146a", null ],
      [ "VE_TYPE_STEAM", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a949cdaf00d2b349e3a1b549d52df2947", null ],
      [ "VE_TYPE_DIESEL", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4aabe24d5e34ee128e0fe7bc809338e222", null ],
      [ "VE_TYPE_ELECTRIC", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a5376a283ac0c5137a38012a70713ab8a", null ],
      [ "VE_DISABLE_EFFECT", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a8116702de1a43110661f214870a2a5e5", null ],
      [ "VE_ADVANCED_EFFECT", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a701977fc170b3323b62aef5ca1423d48", null ],
      [ "VE_DISABLE_WAGON_POWER", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4afe30fb7981ba245e85ac22374f0dac6f", null ],
      [ "VE_DEFAULT", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4ab8c532282649649ad1fde80fc48e97b1", null ]
    ] ],
    [ "VisualEffectSpawnModel", "df/d74/vehicle__base_8h.html#a94faeafbf11d722094ae3ee6d3a35ec7", [
      [ "VESM_NONE", "df/d74/vehicle__base_8h.html#a94faeafbf11d722094ae3ee6d3a35ec7ab78e719815bfafe48351fe13730fab55", null ],
      [ "VESM_STEAM", "df/d74/vehicle__base_8h.html#a94faeafbf11d722094ae3ee6d3a35ec7a1bb23631d3f05386eb7c514157071b3b", null ],
      [ "VESM_DIESEL", "df/d74/vehicle__base_8h.html#a94faeafbf11d722094ae3ee6d3a35ec7a45066f10eae7813595e001ca63af44b9", null ],
      [ "VESM_ELECTRIC", "df/d74/vehicle__base_8h.html#a94faeafbf11d722094ae3ee6d3a35ec7a066d75bcb24422b69e53ad7b56c475ca", null ],
      [ "VESM_END", "df/d74/vehicle__base_8h.html#a94faeafbf11d722094ae3ee6d3a35ec7a5d1094cf18169304effb29131ac81929", null ]
    ] ],
    [ "FixOldVehicles", "df/d74/vehicle__base_8h.html#a95f11278a83efdf874bbe9117e0a97d5", null ],
    [ "GetVehicleDescription", "df/d74/vehicle__base_8h.html#a8816ffcf47aad3178279f76a2bb080e1", null ],
    [ "LoadOldVehicle", "df/d74/vehicle__base_8h.html#a53a5946be45ee9e9a9b211e70b080e7f", null ],
    [ "_vehicle_pool", "df/d74/vehicle__base_8h.html#af7020670644085386e70c310d2a137a9", null ],
    [ "INVALID_COORD", "df/d74/vehicle__base_8h.html#a74f99d53b4060a48bb8edb37b2406fb8", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/df/d74/vehicle__base_8h.js <==
var vehicle__base_8h =
[
    [ "NewGRFCache", "db/d1f/structNewGRFCache.html", "db/d1f/structNewGRFCache" ],
    [ "VehicleCache", "d9/d7d/structVehicleCache.html", "d9/d7d/structVehicleCache" ],
    [ "VehicleSpriteSeq", "d5/d52/structVehicleSpriteSeq.html", "d5/d52/structVehicleSpriteSeq" ],
    [ "MutableSpriteCache", "dd/d19/structMutableSpriteCache.html", "dd/d19/structMutableSpriteCache" ],
    [ "RefitDesc", "d1/de1/structRefitDesc.html", "d1/de1/structRefitDesc" ],
    [ "Vehicle", "d0/dba/structVehicle.html", "d0/dba/structVehicle" ],
    [ "OrderIterator", "d1/d54/structVehicle_1_1OrderIterator.html", "d1/d54/structVehicle_1_1OrderIterator" ],
    [ "IterateWrapper", "dc/d14/structVehicle_1_1IterateWrapper.html", "dc/d14/structVehicle_1_1IterateWrapper" ],
    [ "SpecializedVehicle", "d5/d32/structSpecializedVehicle.html", "d5/d32/structSpecializedVehicle" ],
    [ "FreeUnitIDGenerator", "dd/d52/structFreeUnitIDGenerator.html", "dd/d52/structFreeUnitIDGenerator" ],
    [ "VehiclePool", "df/d74/vehicle__base_8h.html#ae009766a55a373630b73d4da5527aa49", null ],
    [ "GroundVehicleSubtypeFlags", "df/d74/vehicle__base_8h.html#a475541e2c3751ab4cdbbd462e5234c0d", [
      [ "GVSF_FRONT", "df/d74/vehicle__base_8h.html#a475541e2c3751ab4cdbbd462e5234c0da7f80cdde6f9512987ac9c2eb3f230b49", null ],
      [ "GVSF_ARTICULATED_PART", "df/d74/vehicle__base_8h.html#a475541e2c3751ab4cdbbd462e5234c0da13b8cbca661303a477a18b2b4374b4e1", null ],
      [ "GVSF_WAGON", "df/d74/vehicle__base_8h.html#a475541e2c3751ab4cdbbd462e5234c0dabb276682c9516f01f31a632b7793a922", null ],
      [ "GVSF_ENGINE", "df/d74/vehicle__base_8h.html#a475541e2c3751ab4cdbbd462e5234c0dac6cdd99aad9394764b5371eb118dba76", null ],
      [ "GVSF_FREE_WAGON", "df/d74/vehicle__base_8h.html#a475541e2c3751ab4cdbbd462e5234c0dab1ee1247b67762752ac3e36838c04ef7", null ],
      [ "GVSF_MULTIHEADED", "df/d74/vehicle__base_8h.html#a475541e2c3751ab4cdbbd462e5234c0da86f2c03e45fd1fbc14ec2ba0bb7a0d7a", null ]
    ] ],
    [ "NewGRFCacheValidValues", "df/d74/vehicle__base_8h.html#a97190ca989d0b359655a18b4722b7d6c", [
      [ "NCVV_POSITION_CONSIST_LENGTH", "df/d74/vehicle__base_8h.html#a97190ca989d0b359655a18b4722b7d6ca2c2aab4770602781883f87b6d8d2c546", null ],
      [ "NCVV_POSITION_SAME_ID_LENGTH", "df/d74/vehicle__base_8h.html#a97190ca989d0b359655a18b4722b7d6ca6a9bed0fbb26e12b8ea7400eea56de42", null ],
      [ "NCVV_CONSIST_CARGO_INFORMATION", "df/d74/vehicle__base_8h.html#a97190ca989d0b359655a18b4722b7d6ca234159842b57b3f3cf3cccc71daf1c7b", null ],
      [ "NCVV_COMPANY_INFORMATION", "df/d74/vehicle__base_8h.html#a97190ca989d0b359655a18b4722b7d6ca1fd5696aa9d674cd19f3f61c5ec6642c", null ],
      [ "NCVV_POSITION_IN_VEHICLE", "df/d74/vehicle__base_8h.html#a97190ca989d0b359655a18b4722b7d6cac5a52081cfe3b22b83b82945dcedd736", null ],
      [ "NCVV_END", "df/d74/vehicle__base_8h.html#a97190ca989d0b359655a18b4722b7d6caf259659a5cd9def2fe25c84b75a57225", null ]
    ] ],
    [ "VehicleFlags", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7a", [
      [ "VF_LOADING_FINISHED", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aaee56c17502c55d5bde3de57f06e43b01", null ],
      [ "VF_CARGO_UNLOADING", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aa748e67d3dbc538693603017d41d3132a", null ],
      [ "VF_BUILT_AS_PROTOTYPE", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aa6af17c90853fe89b17791602f0be9ef0", null ],
      [ "VF_TIMETABLE_STARTED", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aaf2a9f8891396be7414e5d37fd6e66696", null ],
      [ "VF_AUTOFILL_TIMETABLE", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aac941394da43cb9fc99e37801fd395603", null ],
      [ "VF_AUTOFILL_PRES_WAIT_TIME", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aae699a90ef294038d061380cec2680912", null ],
      [ "VF_STOP_LOADING", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aa27c012b7139ac9e9d9b321929c8764c3", null ],
      [ "VF_PATHFINDER_LOST", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aad89bed75b420510be68cd254426a01b8", null ],
      [ "VF_SERVINT_IS_CUSTOM", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aaf0b635e74343f06e2d461e26652c89a2", null ],
      [ "VF_SERVINT_IS_PERCENT", "df/d74/vehicle__base_8h.html#a6f71ae83254cc7417ec04e6ac2a55f7aa4a664a2c0c83bdcaa9ba3d8fa612cf32", null ]
    ] ],
    [ "VehStatus", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4ec", [
      [ "VS_HIDDEN", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4ecacc5dfba7e128cac462925a6564a55a97", null ],
      [ "VS_STOPPED", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4ecaad499f07ddcf89b774b972c1eec71bb9", null ],
      [ "VS_UNCLICKABLE", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4eca31366b8e7860d2100059a7cfa3a64937", null ],
      [ "VS_DEFPAL", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4ecaeb25e06ebad9abc16e8966815ee60126", null ],
      [ "VS_TRAIN_SLOWING", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4eca5ae3d8fea88773afcc312f721d385ce5", null ],
      [ "VS_SHADOW", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4eca82271078c80dc08bdc23e1a7eddc72fd", null ],
      [ "VS_AIRCRAFT_BROKEN", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4eca6860fc59f73e91177c928b2497d45156", null ],
      [ "VS_CRASHED", "df/d74/vehicle__base_8h.html#a9831102d1e5611a5ce3a06b27a21b4ecae36b782cf9c378a7f06727ecdab935e9", null ]
    ] ],
    [ "VisualEffect", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4", [
      [ "VE_OFFSET_START", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4ac84ac123de33e694a50ad59356b15485", null ],
      [ "VE_OFFSET_COUNT", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a6bcab2e0b1a59f01baad45ddbf832408", null ],
      [ "VE_OFFSET_CENTRE", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a41c2bdecc196b8d5c8c076b1fc080458", null ],
      [ "VE_TYPE_START", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a65429232930562e61d22b43e6d21e1d3", null ],
      [ "VE_TYPE_COUNT", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a3e226d79eb465e44dade4cf11bb81385", null ],
      [ "VE_TYPE_DEFAULT", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a0574594bd49aef1310099f6e9310146a", null ],
      [ "VE_TYPE_STEAM", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a949cdaf00d2b349e3a1b549d52df2947", null ],
      [ "VE_TYPE_DIESEL", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4aabe24d5e34ee128e0fe7bc809338e222", null ],
      [ "VE_TYPE_ELECTRIC", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a5376a283ac0c5137a38012a70713ab8a", null ],
      [ "VE_DISABLE_EFFECT", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a8116702de1a43110661f214870a2a5e5", null ],
      [ "VE_ADVANCED_EFFECT", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4a701977fc170b3323b62aef5ca1423d48", null ],
      [ "VE_DISABLE_WAGON_POWER", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4afe30fb7981ba245e85ac22374f0dac6f", null ],
      [ "VE_DEFAULT", "df/d74/vehicle__base_8h.html#aa897e3504ebb3e551a862faecbde9ac4ab8c532282649649ad1fde80fc48e97b1", null ]
    ] ],
    [ "VisualEffectSpawnModel", "df/d74/vehicle__base_8h.html#a94faeafbf11d722094ae3ee6d3a35ec7", [
      [ "VESM_NONE", "df/d74/vehicle__base_8h.html#a94faeafbf11d722094ae3ee6d3a35ec7ab78e719815bfafe48351fe13730fab55", null ],
      [ "VESM_STEAM", "df/d74/vehicle__base_8h.html#a94faeafbf11d722094ae3ee6d3a35ec7a1bb23631d3f05386eb7c514157071b3b", null ],
      [ "VESM_DIESEL", "df/d74/vehicle__base_8h.html#a94faeafbf11d722094ae3ee6d3a35ec7a45066f10eae7813595e001ca63af44b9", null ],
      [ "VESM_ELECTRIC", "df/d74/vehicle__base_8h.html#a94faeafbf11d722094ae3ee6d3a35ec7a066d75bcb24422b69e53ad7b56c475ca", null ],
      [ "VESM_END", "df/d74/vehicle__base_8h.html#a94faeafbf11d722094ae3ee6d3a35ec7a5d1094cf18169304effb29131ac81929", null ]
    ] ],
    [ "FixOldVehicles", "df/d74/vehicle__base_8h.html#a95f11278a83efdf874bbe9117e0a97d5", null ],
    [ "GetVehicleDescription", "df/d74/vehicle__base_8h.html#a8816ffcf47aad3178279f76a2bb080e1", null ],
    [ "LoadOldVehicle", "df/d74/vehicle__base_8h.html#a53a5946be45ee9e9a9b211e70b080e7f", null ],
    [ "_vehicle_pool", "df/d74/vehicle__base_8h.html#af7020670644085386e70c310d2a137a9", null ],
    [ "INVALID_COORD", "df/d74/vehicle__base_8h.html#a74f99d53b4060a48bb8edb37b2406fb8", null ]
];
